# Changelog

## [2.7.3](https://github.com/AEGIS-GAME/aegis/compare/aegis-v2.7.2...aegis-v2.7.3) (2025-09-14)


### Bug Fixes

* **just to force a aegis release:** . ([36a8b9c](https://github.com/AEGIS-GAME/aegis/commit/36a8b9cebef495eed3ce8f02b813ed2a95fda448))

## [2.7.2](https://github.com/AEGIS-GAME/aegis/compare/aegis-v2.7.1...aegis-v2.7.2) (2025-09-12)


### Bug Fixes

* **ci:** release wrong platforms ([ecbec71](https://github.com/AEGIS-GAME/aegis/commit/ecbec71816f5f2be925f38ef0fb60ef8a42bbc6c))

## [2.7.1](https://github.com/AEGIS-GAME/aegis/compare/aegis-v2.7.0...aegis-v2.7.1) (2025-09-12)


### Bug Fixes

* **workflows:** add missing steps ([4a24ef9](https://github.com/AEGIS-GAME/aegis/commit/4a24ef930a0fa86da488b1dbfcbde4c63feeabad))

## [2.7.0](https://github.com/AEGIS-GAME/aegis/compare/aegis-v2.6.4...aegis-v2.7.0) (2025-09-12)


### Features

* **new workflow:** move release into one workflow ([bf76e95](https://github.com/AEGIS-GAME/aegis/commit/bf76e95af4b9afdefd75a0a9cc1c09e1d29505da))

## [2.6.4](https://github.com/AEGIS-GAME/aegis/compare/aegis-v2.6.3...aegis-v2.6.4) (2025-09-12)


### Bug Fixes

* **tryign to force a release:** hate google ([#50](https://github.com/AEGIS-GAME/aegis/issues/50)) ([93179c4](https://github.com/AEGIS-GAME/aegis/commit/93179c4935cf98ee3b50197d0a60b034db0905fd))
